@@ -22,6 +22,14 @@ NULL
 #' @keywords data
 NULL
 
+#' Seed geographical dictionary in French
+#'
+#' @name data_dictionary_newsmap_fr
+#' @docType data
+#' @author Claude Grasland \email{claude.grasland@parisgeo.cnrs.fr}
+#' @keywords data
+NULL
+
 #' Seed geographical dictionary in Spanish
 #'
 #' @name data_dictionary_newsmap_es
@@ -37,3 +45,19 @@ NULL
 #' @author Katerina Tertytchnaya \email{katerina.tertytchnaya@gmail.com}
 #' @keywords data
 NULL
+
+#' Seed geographical dictionary in Chinese (simplified)
+#'
+#' @name data_dictionary_newsmap_zh_cn
+#' @docType data
+#' @author Ke Cheng \email{kecheng.ac@gmail.com}
+#' @keywords data
+NULL
+
+#' Seed geographical dictionary in Chinese (traditional)
+#'
+#' @name data_dictionary_newsmap_zh_tw
+#' @docType data
+#' @author Chung-hong Chan \email{chainsawtiney@gmail.com}
+#' @keywords data
+NULL
